# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyCreateResponse(Model):
    """ApiKeyCreateResponse.

    :param api_key: The API key. This value cannot be retrieved again after it
     is created.
    :type api_key: str
    :param api_key_id: The identifier of the API key
    :type api_key_id: int
    :param api_key_name: The name of the API key
    :type api_key_name: str
    :param api_key_description: A description of the API key
    :type api_key_description: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'api_key': {'key': 'apiKey', 'type': 'str'},
        'api_key_id': {'key': 'apiKeyId', 'type': 'int'},
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
    }

    def __init__(self, api_key=None, api_key_id=None, api_key_name=None, api_key_description=None, created_by=None):
        super(ApiKeyCreateResponse, self).__init__()
        self.api_key = api_key
        self.api_key_id = api_key_id
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description
        self.created_by = created_by
