# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensityEuiCommodity(Model):
    """PlaceDigestEnergyUseIntensityEuiCommodity.

    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param use: The use for the commodity
    :type use: float
    :param use_percent: The percent of the building's energy used by the
     commodity
    :type use_percent: float
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'use': {'key': 'use', 'type': 'float'},
        'use_percent': {'key': 'usePercent', 'type': 'float'},
    }

    def __init__(self, commodity_id=None, commodity_code=None, commodity_info=None, use=None, use_percent=None):
        super(PlaceDigestEnergyUseIntensityEuiCommodity, self).__init__()
        self.commodity_id = commodity_id
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.use = use
        self.use_percent = use_percent
