# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillIdResponse(Model):
    """BillIdResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
    }

    def __init__(self, bill_id=None):
        super(BillIdResponse, self).__init__()
        self.bill_id = bill_id
