# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogDetailsResponse(Model):
    """WebhookLogDetailsResponse.

    :param url: The URL that the webhook is configured for
    :type url: str
    :param request: The request that was sent from the webhook (headers and
     body)
    :type request: str
    :param response: The response that was received from the configured url
     (headers and body)
    :type response: str
    :param result: The HTTP status code that was received from the configured
     url
    :type result: str
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
        'request': {'key': 'request', 'type': 'str'},
        'response': {'key': 'response', 'type': 'str'},
        'result': {'key': 'result', 'type': 'str'},
    }

    def __init__(self, url=None, request=None, response=None, result=None):
        super(WebhookLogDetailsResponse, self).__init__()
        self.url = url
        self.request = request
        self.response = response
        self.result = result
