# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitMismatchChild(Model):
    """UnitMismatchChild.

    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param count:
    :type count: int
    """

    _attribute_map = {
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, unit=None, count=None):
        super(UnitMismatchChild, self).__init__()
        self.unit = unit
        self.count = count
