# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchSettings(Model):
    """BatchSettings.

    :param batch_mode:  <span class='property-internal'>One of use existing
     batch, new batch, new self-contained batch </span>
    :type batch_mode: str
    :param new_batch_code: optional- if not provided, we will autocreate the
     batch code.
     If useExistingBatch is true, this value will be ignored <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type new_batch_code: str
    """

    _validation = {
        'new_batch_code': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_mode': {'key': 'batchMode', 'type': 'str'},
        'new_batch_code': {'key': 'newBatchCode', 'type': 'str'},
    }

    def __init__(self, batch_mode=None, new_batch_code=None):
        super(BatchSettings, self).__init__()
        self.batch_mode = batch_mode
        self.new_batch_code = new_batch_code
