# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionResponse(Model):
    """ReportDistributionResponse.

    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param mailers: Array of report mailers processed, with their results
    :type mailers: list[~energycap.sdk.models.ReportMailerChild]
    """

    _attribute_map = {
        'user': {'key': 'user', 'type': 'UserChild'},
        'mailers': {'key': 'mailers', 'type': '[ReportMailerChild]'},
    }

    def __init__(self, user=None, mailers=None):
        super(ReportDistributionResponse, self).__init__()
        self.user = user
        self.mailers = mailers
