# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogRequest(Model):
    """WebhookLogRequest.

    :param status_code: The HTTP status code <span
     class='property-internal'>Required (defined)</span>
    :type status_code: int
    :param response: The response JSON <span
     class='property-internal'>Required (defined)</span>
    :type response: str
    """

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
        'response': {'key': 'response', 'type': 'str'},
    }

    def __init__(self, status_code=None, response=None):
        super(WebhookLogRequest, self).__init__()
        self.status_code = status_code
        self.response = response
