# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NamedPeriod(Model):
    """NamedPeriod.

    :param period_name:
    :type period_name: str
    :param period:
    :type period: int
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'period': {'key': 'period', 'type': 'int'},
    }

    def __init__(self, period_name=None, period=None):
        super(NamedPeriod, self).__init__()
        self.period_name = period_name
        self.period = period
