# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportChild(Model):
    """ReportChild.

    :param version:
    :type version: str
    :param report_id:
    :type report_id: int
    :param report_code:
    :type report_code: str
    :param report_info:
    :type report_info: str
    :param report_type:
    :type report_type: ~energycap.sdk.models.ReportType
    :param description:
    :type description: str
    :param is_landscape:
    :type is_landscape: bool
    :param last_updated:
    :type last_updated: datetime
    :param tags:
    :type tags: list[~energycap.sdk.models.TagChild]
    :param export_formats:
    :type export_formats: list[~energycap.sdk.models.ExportFormatChild]
    """

    _attribute_map = {
        'version': {'key': 'version', 'type': 'str'},
        'report_id': {'key': 'reportId', 'type': 'int'},
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'report_info': {'key': 'reportInfo', 'type': 'str'},
        'report_type': {'key': 'reportType', 'type': 'ReportType'},
        'description': {'key': 'description', 'type': 'str'},
        'is_landscape': {'key': 'isLandscape', 'type': 'bool'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
        'tags': {'key': 'tags', 'type': '[TagChild]'},
        'export_formats': {'key': 'exportFormats', 'type': '[ExportFormatChild]'},
    }

    def __init__(self, version=None, report_id=None, report_code=None, report_info=None, report_type=None, description=None, is_landscape=None, last_updated=None, tags=None, export_formats=None):
        super(ReportChild, self).__init__()
        self.version = version
        self.report_id = report_id
        self.report_code = report_code
        self.report_info = report_info
        self.report_type = report_type
        self.description = description
        self.is_landscape = is_landscape
        self.last_updated = last_updated
        self.tags = tags
        self.export_formats = export_formats
