# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceHierarchyResponse(Model):
    """EnergyStarPlaceHierarchyResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param metrics: ENERGY STAR score data for the place
     If there are multiple places returned in the response, will be the most
     recent score
    :type metrics: list[~energycap.sdk.models.EnergyStarPlaceMetricsResponse]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'metrics': {'key': 'metrics', 'type': '[EnergyStarPlaceMetricsResponse]'},
    }

    def __init__(self, place=None, place_size=None, metrics=None):
        super(EnergyStarPlaceHierarchyResponse, self).__init__()
        self.place = place
        self.place_size = place_size
        self.metrics = metrics
