# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCopy(Model):
    """ListCopy.

    :param list_info: The list name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type list_info: str
    :param list_description: The list description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type list_description: str
    """

    _validation = {
        'list_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'list_description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
    }

    def __init__(self, list_info, list_description=None):
        super(ListCopy, self).__init__()
        self.list_info = list_info
        self.list_description = list_description
