# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FailedReadingResponse(Model):
    """FailedReadingResponse.

    :param channel_id:
    :type channel_id: int
    :param channel_import_id:
    :type channel_import_id: str
    :param meter_import_id:
    :type meter_import_id: str
    :param observation_type_code:
    :type observation_type_code: str
    :param unit_code:
    :type unit_code: str
    :param channel_interval_in_seconds:
    :type channel_interval_in_seconds: int
    :param readings:
    :type readings: list[~energycap.sdk.models.FailedReadings]
    :param error:
    :type error: str
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'meter_import_id': {'key': 'meterImportId', 'type': 'str'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
        'readings': {'key': 'readings', 'type': '[FailedReadings]'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, channel_id=None, channel_import_id=None, meter_import_id=None, observation_type_code=None, unit_code=None, channel_interval_in_seconds=None, readings=None, error=None):
        super(FailedReadingResponse, self).__init__()
        self.channel_id = channel_id
        self.channel_import_id = channel_import_id
        self.meter_import_id = meter_import_id
        self.observation_type_code = observation_type_code
        self.unit_code = unit_code
        self.channel_interval_in_seconds = channel_interval_in_seconds
        self.readings = readings
        self.error = error
