# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMappingChild(Model):
    """EnergyStarCommodityMappingChild.

    :param pm_unit_code: The unit code in Portfolio Manager
    :type pm_unit_code: str
    :param supported_pm_commodities: The commodity code in Portfolio Manager
    :type supported_pm_commodities: list[str]
    """

    _attribute_map = {
        'pm_unit_code': {'key': 'pmUnitCode', 'type': 'str'},
        'supported_pm_commodities': {'key': 'supportedPmCommodities', 'type': '[str]'},
    }

    def __init__(self, pm_unit_code=None, supported_pm_commodities=None):
        super(EnergyStarCommodityMappingChild, self).__init__()
        self.pm_unit_code = pm_unit_code
        self.supported_pm_commodities = supported_pm_commodities
