# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportEmail(Model):
    """ReportEmail.

    :param email_message_id: Unique identifier for the email sent to the
     recipient
     Will be null if the report email couldn't be sent
    :type email_message_id: str
    :param subject: Email subject
     Will be null if the report email couldn't be sent
    :type subject: str
    :param recipient: Email recipient
     Will be a list of all intended email addresses if the report email
     couldn't be sent
    :type recipient: str
    :param specific_report_id: Unique identifier of the specific instance of
     the base report
    :type specific_report_id: int
    :param specific_report_info: Specific report name
    :type specific_report_info: str
    :param specific_report_code: Specific report code
    :type specific_report_code: str
    :param base_report_id: Unique identifier of the base report
    :type base_report_id: int
    :param base_report_code: Base report code
    :type base_report_code: str
    :param base_report_info: Base report name
    :type base_report_info: str
    """

    _attribute_map = {
        'email_message_id': {'key': 'emailMessageId', 'type': 'str'},
        'subject': {'key': 'subject', 'type': 'str'},
        'recipient': {'key': 'recipient', 'type': 'str'},
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'specific_report_info': {'key': 'specificReportInfo', 'type': 'str'},
        'specific_report_code': {'key': 'specificReportCode', 'type': 'str'},
        'base_report_id': {'key': 'baseReportId', 'type': 'int'},
        'base_report_code': {'key': 'baseReportCode', 'type': 'str'},
        'base_report_info': {'key': 'baseReportInfo', 'type': 'str'},
    }

    def __init__(self, email_message_id=None, subject=None, recipient=None, specific_report_id=None, specific_report_info=None, specific_report_code=None, base_report_id=None, base_report_code=None, base_report_info=None):
        super(ReportEmail, self).__init__()
        self.email_message_id = email_message_id
        self.subject = subject
        self.recipient = recipient
        self.specific_report_id = specific_report_id
        self.specific_report_info = specific_report_info
        self.specific_report_code = specific_report_code
        self.base_report_id = base_report_id
        self.base_report_code = base_report_code
        self.base_report_info = base_report_info
